@@ -26,12 +26,9 @@ import (
 var (
 	canRun  = true  // whether we can run go or ./testgb
 	canRace = false // whether we can run the race detector
-	canCgo  = false // whether we can use cgo
 
 	exeSuffix string // ".exe" on Windows
 
-	skipExternalBuilder = false // skip external tests on this builder
-
 	testgb string = "testgb"
 )
 
@@ -1385,11 +1382,16 @@ func main() { println("hello world") }
 	if runtime.GOOS == goos {
 		goos = "linux"
 	}
+	goarch := "386"
+	if runtime.GOARCH == goarch {
+		goarch = "amd64"
+	}
 	gb.setenv("TMP", tmpdir)
 	gb.setenv("GOOS", goos)
+	gb.setenv("GOARCH", goarch)
 	gb.run("build")
 	gb.mustBeEmpty(tmpdir)
-	name := fmt.Sprintf("p-%s-%s", goos, runtime.GOARCH)
+	name := fmt.Sprintf("p-%s-%s", goos, goarch)
 	if goos == "windows" {
 		name += ".exe"
 	}
